@@ -10,7 +10,7 @@ use warnings;
 no warnings 'uninitialized';
 
 use vars qw($VERSION);
-$VERSION = '0.014';
+$VERSION = '0.015';
 
 use DateTime;
 
@@ -41,29 +41,36 @@ sub mark_done {
     return $self->_mark_done( $entry );
 }
 
-sub start_cron {
-    my $cron = shift;
+
+# starts a cron thread. All this does is queues up a message in the engine to check the cron.
+sub start {
+    my $cfg = shift;
     while( 1 ) {
-        my $cron_entries = $cron->entries();
-        # TODO : make sure nothing volatile is here
-        # ALSO TODO : for security sake, only allow this to call a yote method?
-        for my $entry (@$cron_entries) {
-            # TODO : Just queue up a cron in the execution engine
-            $cron->_mark_done( $entry );
-            my $script = $entry->get_script();
-            print STDERR "EVAL $script\n";
-            eval "$script";
-            print STDERR "Done EVAL\n";
-            if( $@ ) {
-                print STDERR "Error in Cron : $@ $!\n";
-            } 
-            Yote::ObjProvider::start_transaction();
-            Yote::ObjProvider::stow_all();
-            Yote::ObjProvider::flush_all_volatile();
-            Yote::ObjProvider::commit_transaction();
-        } #each cron entry
-    } #endless loop
-} #start_cron
+        my $sock = new IO::Socket::INET( "127.0.0.1:$cfg->{internal_port}" );
+        print $sock "CRON";
+        close $sock;
+        sleep 50;
+    }
+} #start
+
+sub check {
+    my $cron = shift;
+
+    my $cron_entries = $cron->entries();
+    # TODO : make sure nothing volatile is here
+    # ALSO TODO : for security sake, only allow this to call a yote method?
+    for my $entry (@$cron_entries) {
+        # TODO : Just queue up a cron in the execution engine
+        $cron->_mark_done( $entry );
+        my $script = $entry->get_script();
+        print STDERR "EVAL $script\n";
+        eval "$script";
+        print STDERR "Done EVAL\n";
+        if( $@ ) {
+            print STDERR "Error in Cron : $@ $!\n";
+        } 
+    } #each cron entry
+} #check
 
 sub update_entry {
     my( $self, $entry, $acct ) = @_;
@@ -245,7 +252,7 @@ Returns a list of the entries that should be run at the time this was called.
 
 Marks this entry as done. This causes any repeat_times to decrement, and removes appropriate scheduled times.
 
-=item start_cron( $entry )
+=item start( $entry )
 
 Starts main loop for cron.
 
