@@ -11,7 +11,7 @@ use parent 'Yote::Obj';
 sub new_with_same_permissions {
     my( $self, $args, $account ) = @_;
     die "Permissions Error" unless $self->_check_access( $account, 1, '' );
-    return new Yote::RootObj( $args );
+    return $self->new( $args );
 } #new_with_same_permissions
 
 # only root may edit any fields. public fields are readable by all.
